==> lambda-nodejs-1.69.0-sources.jar: software/amazon/awscdk/services/lambda/nodejs/Bundling.java <==
package software.amazon.awscdk.services.lambda.nodejs;

/**
 * (experimental) Bundling.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.13.0 (build 385c325)", date = "2020-10-19T20:38:24.358Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.nodejs.$Module.class, fqn = "@aws-cdk/aws-lambda-nodejs.Bundling")
public class Bundling extends software.amazon.jsii.JsiiObject {

    protected Bundling(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Bundling(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Bundling() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * (experimental) Parcel bundled Lambda asset code.
     * <p>
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.AssetCode parcel(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.nodejs.ParcelOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.lambda.nodejs.Bundling.class, "parcel", software.amazon.awscdk.services.lambda.AssetCode.class, new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }
}

==> lambda-nodejs-1.71.0-sources.jar: software/amazon/awscdk/services/lambda/nodejs/Bundling.java <==
package software.amazon.awscdk.services.lambda.nodejs;

/**
 * (experimental) Bundling.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.14.0 (build 729554b)", date = "2020-10-29T17:34:18.608Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.nodejs.$Module.class, fqn = "@aws-cdk/aws-lambda-nodejs.Bundling")
public class Bundling extends software.amazon.jsii.JsiiObject {

    protected Bundling(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Bundling(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Bundling() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * (experimental) Parcel bundled Lambda asset code.
     * <p>
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.AssetCode parcel(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.nodejs.ParcelOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.lambda.nodejs.Bundling.class, "parcel", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.AssetCode.class), new Object[] { java.util.Objects.requireNonNull(options, "options is required") });
    }
}
